*******************
Dorado Documentation Overview
*******************

(Digitized Observatory Resources for Automated Data Operations)


Overview
=============

.. image:: https://img.shields.io/badge/Made%40-YorkObservatory-red
    :target: https://observatory.info.yorku.ca
    :alt: Made at YorkObservatory
.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge
.. image:: https://readthedocs.org/projects/dorado/badge/?version=latest
    :target: https://dorado.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://img.shields.io/github/last-commit/Mucephie/DORADO
    :target: https://github.com/Mucephie/DORADO
    :alt: Last Commit
.. image:: https://img.shields.io/github/issues/Mucephie/DORADO
    :target: https://github.com/Mucephie/DORADO/issues
    :alt: GitHub issues
.. image:: https://img.shields.io/github/v/release/Mucephie/DORADO?include_prereleases
    :target: https://github.com/Mucephie/DORADO
    :alt: GitHub release (latest by date including pre-releases)

.. image:: https://img.shields.io/pypi/status/dorado
    :target: https://pypi.org/project/dorado/
    :alt: PyPI - Status
.. image:: https://img.shields.io/pypi/v/dorado
    :target: https://pypi.org/project/dorado/#history
    :alt: PyPI
.. image:: https://img.shields.io/pypi/format/dorado  
    :target: https://pypi.org/project/dorado/#files
    :alt: PyPI - Format
.. image:: https://img.shields.io/pypi/l/dorado   
    :target: https://pypi.org/project/dorado/
    :alt: PyPI - License
.. image:: https://img.shields.io/pypi/dm/dorado   
    :target: https://pypi.org/project/dorado/#files
    :alt: PyPI - Downloads



DORADO
-------------

Digitized Observatory Resources for Automated Data Operations (DORADO) is a python based expansion of astropy (and affiliated packages) that aims to be a simple and common framework for data reduction tailored for life at the Allan I. Carswell Observatory at York university, Toronto, Ontario, Canada

        .. admonition:: ☣⚠ DORADO is in beta ⚠☣

                DORADO is in beta and as such is highly experimental and still a work in progress. While still in active development DORADO may still be used and experimented with; but a stable channel will not be created until DORADO enters a stable phase in the future.

                Use of DORADO while in beta will not result in any risk to your computer or hardware, but may affect stability of software that are written with DORADO or the quality of data that is produced using DORADO.

                During the beta, documentation and code commenting may be subpar as many things will being changing regularly with new code being written and rewritten and in-line testing appearing temporarily.
    

Getting started with dorado:
--------------

For help getting started see: :doc:`Getting Started</dorado/GettingStarted>`


:doc:`Getting Started</dorado/GettingStarted>`

:doc:`Core</dorado/core>`

:doc:`Reader</dorado/reader>`

:doc:`Ceres</dorado/ceres>`

:doc:`Target</dorado/target>`

:doc:`Dorphot</dorado/dorphot>`

:doc:`Timeseries</dorado/timeseries>`

:doc:`Graphing</dorado/graphing>`

:doc:`Putting it Together</dorado/puttingItTogether>`



Installation
------------

Install dorado by running: ``pip install dorado``.

    .. note:: The `dorado <https://pypi.org/project/dorado/>`_ project on `PyPI <https://pypi.org/>`_ .


Examples
--------

In the near future examples, tutorials, and pre-made use scripts will be located here. The first release of Dorado should ship with an example pipeline and data formatting tutorial.

Reference/API
=============

.. automodapi:: dorado

Contribute
----------

We love contributions! dorado is open source, built on open source, and we'd love to have you hang out in our community.

**Imposter syndrome disclaimer**: We want your help. No, really.

There may be a little voice inside your head that is telling you that you're not ready to be an open source contributor; that your skills aren't nearly good enough to contribute. What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong. If you can write code at all, you can contribute code to open source. Contributing to open source projects is a fantastic way to advance one's coding skills. Writing perfect code isn't the measure of a good developer (that would disqualify all of us!); it's trying to create something, making mistakes, and learning from those mistakes. That's how we all improve, and we are happy to help others learn.

Being an open source contributor doesn't just mean writing code, either. You can help out by writing documentation, tests, or even giving feedback about the project (and yes - that includes giving feedback about the contribution process). Some of these contributions may be the most valuable to the project as a whole, because you're coming to the project with fresh eyes, so you can see the errors and assumptions that seasoned contributors have glossed over.

.. Note:: This disclaimer was originally written by
        `Adrienne Lowe <https://github.com/adriennefriend>`_ for a
        `PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted by dorado based on its use in the README file for the
        `MetPy project <https://github.com/Unidata/MetPy>`_.


- Issue Tracker: `github.com/mucephie/dorado/issues <github.com/mucephie/dorado/issues>`_
- Source Code: `github.com/mucephie/dorado <github.com/mucephie/dorado>`_

Support/Contact
-------

If you have any questions or would like to contribute to DORADO, please contact `@mucephie <https://github.com/Mucephie>`_ at <mucephie@my.yorku.ca>. If you are interested in the Allan I. Carswell observatory at York university, you can find more information at our `website <http://observatory.info.yorku.ca/>`_.  

License
-------


This project is Copyright (c) Mucephie and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause license. See the licenses folder for more information.

